==> fvtt-hero-system-6-v10.0.42.tar.gz: fvtt-hero-system-6/modules/hero6-actor-sheet.js <==
/**
 * Extend the basic ActorSheet with some very simple modifications
 * @extends {ActorSheet}
 */

import { Hero6Utility } from "./hero6-utility.js";

/* -------------------------------------------- */
export class Hero6ActorSheet extends ActorSheet {

  /** @override */
  static get defaultOptions() {

    return mergeObject(super.defaultOptions, {
      classes: ["fvtt-hero-system-6", "sheet", "actor"],
      template: "systems/fvtt-hero-system-6/templates/actors/actor-sheet.hbs",
      width: 1124,
      height: 916,
      tabs: [{ navSelector: ".sheet-tabs", contentSelector: ".sheet-body", initial: "main" }],
      dragDrop: [{ dragSelector: ".item-list .item", dropSelector: null }],
      editScore: true
    });
  }

  /* -------------------------------------------- */
  async getData() {
    const objectData = duplicate(this.object.system)

    let formData = {
      title: this.title,
      id: this.actor.id,
      type: this.actor.type,
      img: this.actor.img,
      name: this.actor.name,
      editable: this.isEditable,
      cssClass: this.isEditable ? "editable" : "locked",
      system: objectData,
      characteristics: this.actor.prepareCharac(),
      defenses: duplicate(this.actor.system.defenses),
      movements: duplicate(this.actor.system.movements),
      limited: this.object.limited,
      skills: this.actor.getSkills( ),
      perks: this.actor.getPerks( ),
      powers: await this.actor.getPowers( ),
      talents: this.actor.getTalents( ),
      complications: this.actor.getComplications( ),
      maneuvers: this.actor.getManeuvers( ),
      nonstockmaneuvers: this.actor.getNonStockManeuvers(),
      weapons: this.actor.checkAndPrepareEquipments( duplicate(this.actor.getWeapons()) ),
      armors: this.actor.checkAndPrepareEquipments( duplicate(this.actor.getArmors())),
      shields: this.actor.checkAndPrepareEquipments( duplicate(this.actor.getShields())),
      equipments: this.actor.checkAndPrepareEquipments(duplicate(this.actor.getEquipmentsMoneys()) ),
      subActors: duplicate(this.actor.getSubActors()),
      race: duplicate(this.actor.getRace()),
      encCapacity: this.actor.getEncumbranceCapacity(),
      description: await TextEditor.enrichHTML(this.object.system.biodata.description, {async: true}),
      motivation: await TextEditor.enrichHTML(this.object.system.biodata.motivation, {async: true}),
      quote: await TextEditor.enrichHTML(this.object.system.biodata.quote, {async: true}),
      tactics: await TextEditor.enrichHTML(this.object.system.biodata.tactics, {async: true}),
      campaignuse: await TextEditor.enrichHTML(this.object.system.biodata.campaignuse, {async: true}),
      appearance: await TextEditor.enrichHTML(this.object.system.biodata.appearance, {async: true}),
      notes1: await TextEditor.enrichHTML(this.object.system.biodata.notes1, {async: true}),
      notes2: await TextEditor.enrichHTML(this.object.system.biodata.notes2, {async: true}),
      notes3: await TextEditor.enrichHTML(this.object.system.biodata.notes3, {async: true}),
      notes4: await TextEditor.enrichHTML(this.object.system.biodata.notes4, {async: true}),
      notes5: await TextEditor.enrichHTML(this.object.system.biodata.notes5, {async: true}),
      containersTree: this.actor.containersTree,
      encCurrent: this.actor.encCurrent,
      totalValue: this.actor.totalValue,
      options: this.options,
      owner: this.document.isOwner,
      editScore: this.options.editScore,
      isGM: game.user.isGM
    }
    this.formData = formData;

    console.log("PC : ", formData, this.object);
    return formData;
  }


  /* -------------------------------------------- */
  /** @override */
  activateListeners(html) {
    super.activateListeners(html);

    // Everything below here is only needed if the sheet is editable
    if (!this.options.editable) return;
    
    html.bind("keydown", function(e) { // Ignore Enter in actores sheet
      if (e.keyCode === 13) return false;
    });  

    // Update Inventory Item
    html.find('.item-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      const item = this.actor.items.get( itemId );
      item.sheet.render(true);
    });
    // Delete Inventory Item
    html.find('.item-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      Hero6Utility.confirmDelete(this, li)
    })
    html.find('.item-add').click(ev => {
      let dataType = $(ev.currentTarget).data("type")
      this.actor.createEmbeddedDocuments('Item', [{ name: "NewItem", type: dataType }], { renderSheet: true })
    })
        
    html.find('.equip-activate').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      this.actor.equipActivate( itemId)
    });      
    html.find('.equip-deactivate').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      this.actor.equipDeactivate( itemId)
    });      

    html.find('.subactor-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let actorId = li.data("actor-id");
      let actor = game.actors.get( actorId );
      actor.sheet.render(true);
    });
    
    html.find('.subactor-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let actorId = li.data("actor-id");
      this.actor.delSubActor(actorId);
    });
    html.find('.quantity-minus').click(event => {
      const li = $(event.currentTarget).parents(".item");
      this.actor.incDecQuantity( li.data("item-id"), -1 );
    } );
    html.find('.quantity-plus').click(event => {
      const li = $(event.currentTarget).parents(".item");
      this.actor.incDecQuantity( li.data("item-id"), +1 );
    } );

    html.find('.ammo-minus').click(event => {
      const li = $(event.currentTarget).parents(".item")
      this.actor.incDecAmmo( li.data("item-id"), -1 );
    } );
    html.find('.ammo-plus').click(event => {
      const li = $(event.currentTarget).parents(".item")
      this.actor.incDecAmmo( li.data("item-id"), +1 )
    } );
            
    html.find('.roll-charac').click((event) => {
      const characKey = $(event.currentTarget).data("charac-key");
      this.actor.rollCharac(characKey);
    });
    html.find('.roll-perception').click((event) => {
      this.actor.rollPerception("int");
    });
    
    html.find('.roll-direct').click((event) => {
      const rollFormula = $(event.currentTarget).data("roll-formula")
      const rollSource = $(event.currentTarget).data("roll-source")
      Hero6Utility.processDirectRoll( { actorId: this.actor.id, rollFormula: rollFormula, rollSource: rollSource, mode:"directroll"} )
    });
    
    html.find('.roll-item').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      let itemId = li.data("item-id")
      this.actor.rollItem(itemId);
    });
    html.find('.roll-damage').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      let itemId = li.data("item-id")
      this.actor.rollDamage(itemId);
    });
    html.find('.roll-lift-dice').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      let itemId = li.data("item-id")
      this.actor.rollLiftDice(itemId);
    });
    
    html.find('.roll-weapon').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      const skillId = li.data("item-id")
      this.actor.rollWeapon(skillId)
    });

    html.find('.lock-unlock-sheet').click((event) => {
      this.options.editScore = !this.options.editScore;
      this.render(true);
    });    
    html.find('.item-link a').click((event) => {
      const itemId = $(event.currentTarget).data("item-id");
      const item = this.actor.getOwnedItem(itemId);
      item.sheet.render(true);
    });    
    html.find('.item-equip').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      this.actor.equipItem( li.data("item-id") );
      this.render(true);      
    });

    html.find('.update-field').change(ev => {
      const fieldName = $(ev.currentTarget).data("field-name");
      const fieldType = $(ev.currentTarget).data("dtype");
      let value = ev.currentTarget.value
      if (fieldType.toLowerCase() == "Number") {
        value = Number(value)
      }
      this.actor.update( { [`${fieldName}`]: value } );
    });    
  }
  
  /* -------------------------------------------- */
  /** @override */
  setPosition(options = {}) {
    const position = super.setPosition(options);
    const sheetBody = this.element.find(".sheet-body");
    const bodyHeight = position.height - 192;
    sheetBody.css("height", bodyHeight);
    return position;
  }

  /* -------------------------------------------- */
  async _onDropItem(event, dragData) {
    console.log(">>>>>> DROPPED!!!!")
    const item = fromUuidSync(dragData.uuid)
    if (item == undefined) {
      item = this.actor.items.get( item.id )
    }
    let ret = await this.actor.preprocessItem( event, item, true )
    if ( ret ) {
      super._onDropItem(event, dragData)
    }
  }

  /* -------------------------------------------- */
  /** @override */
  _updateObject(event, formData) {
    // Update the Actor
    return this.object.update(formData);
  }
}

==> fvtt-hero-system-6-v11.0.7.tar.gz: fvtt-hero-system-6/modules/hero6-actor-sheet.js <==
/**
 * Extend the basic ActorSheet with some very simple modifications
 * @extends {ActorSheet}
 */

import { Hero6Utility } from "./hero6-utility.js";

/* -------------------------------------------- */
export class Hero6ActorSheet extends ActorSheet {

  /** @override */
  static get defaultOptions() {

    return mergeObject(super.defaultOptions, {
      classes: ["fvtt-hero-system-6", "sheet", "actor"],
      template: "systems/fvtt-hero-system-6/templates/actors/actor-sheet.hbs",
      width: 1124,
      height: 916,
      tabs: [{ navSelector: ".sheet-tabs", contentSelector: ".sheet-body", initial: "main" }],
      dragDrop: [{ dragSelector: ".item-list .item", dropSelector: null }],
      editScore: true
    });
  }

  /* -------------------------------------------- */
  async getData() {
    const objectData = duplicate(this.object.system)

    let formData = {
      title: this.title,
      id: this.actor.id,
      type: this.actor.type,
      img: this.actor.img,
      name: this.actor.name,
      editable: this.isEditable,
      cssClass: this.isEditable ? "editable" : "locked",
      system: objectData,
      characteristics: this.actor.prepareCharac(),
      defenses: duplicate(this.actor.system.defenses),
      movements: duplicate(this.actor.system.movements),
      limited: this.object.limited,
      skills: this.actor.getSkills( ),
      perks: this.actor.getPerks( ),
      powers: await this.actor.getPowers( ),
      talents: this.actor.getTalents( ),
      complications: this.actor.getComplications( ),
      maneuvers: this.actor.getManeuvers( ),
      nonstockmaneuvers: this.actor.getNonStockManeuvers(),
      allmaneuvers: this.actor.getAllManeuvers(),
      weapons: this.actor.checkAndPrepareEquipments( duplicate(this.actor.getWeapons()) ),
      armors: this.actor.checkAndPrepareEquipments( duplicate(this.actor.getArmors())),
      shields: this.actor.checkAndPrepareEquipments( duplicate(this.actor.getShields())),
      equipments: this.actor.checkAndPrepareEquipments(duplicate(this.actor.getEquipmentsMoneys()) ),
      subActors: duplicate(this.actor.getSubActors()),
      race: duplicate(this.actor.getRace()),
      encCapacity: this.actor.getEncumbranceCapacity(),
      isHold: this.actor.getHoldAction(),
      isAbort: this.actor.getAbortAction(),
      description: await TextEditor.enrichHTML(this.object.system.biodata.description, {async: true}),
      motivation: await TextEditor.enrichHTML(this.object.system.biodata.motivation, {async: true}),
      quote: await TextEditor.enrichHTML(this.object.system.biodata.quote, {async: true}),
      tactics: await TextEditor.enrichHTML(this.object.system.biodata.tactics, {async: true}),
      campaignuse: await TextEditor.enrichHTML(this.object.system.biodata.campaignuse, {async: true}),
      appearance: await TextEditor.enrichHTML(this.object.system.biodata.appearance, {async: true}),
      notes1: await TextEditor.enrichHTML(this.object.system.biodata.notes1, {async: true}),
      notes2: await TextEditor.enrichHTML(this.object.system.biodata.notes2, {async: true}),
      notes3: await TextEditor.enrichHTML(this.object.system.biodata.notes3, {async: true}),
      notes4: await TextEditor.enrichHTML(this.object.system.biodata.notes4, {async: true}),
      notes5: await TextEditor.enrichHTML(this.object.system.biodata.notes5, {async: true}),
      containersTree: this.actor.containersTree,
      encCurrent: this.actor.encCurrent,
      totalValue: this.actor.totalValue,
      options: this.options,
      owner: this.document.isOwner,
      editScore: this.options.editScore,
      isGM: game.user.isGM
    }

    this.formData = formData;
    this.stockManeuverDisplayed = false

    console.log("PC : ", formData, this.object);
    return formData;
  }


  /* -------------------------------------------- */
  /** @override */
  activateListeners(html) {
    super.activateListeners(html);

    // Everything below here is only needed if the sheet is editable
    if (!this.options.editable) return;
    
    /*html.bind("keydown", function(e) { // Ignore Enter in actores sheet
      if (e.keyCode === 13) return false;
    });*/  

    // Update Inventory Item
    html.find('.item-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      const item = this.actor.items.get( itemId );
      item.sheet.render(true);
    });
    // Delete Inventory Item
    html.find('.item-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      Hero6Utility.confirmDelete(this, li)
    })
    html.find('.item-add').click(ev => {
      let dataType = $(ev.currentTarget).data("type")
      this.actor.createEmbeddedDocuments('Item', [{ name: "NewItem", type: dataType }], { renderSheet: true })
    })
        
    html.find('.equip-activate').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      this.actor.equipActivate( itemId)
    });      
    html.find('.equip-deactivate').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      this.actor.equipDeactivate( itemId)
    });      

    html.find('.subactor-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let actorId = li.data("actor-id");
      let actor = game.actors.get( actorId );
      actor.sheet.render(true);
    });
    
    html.find('.subactor-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let actorId = li.data("actor-id");
      this.actor.delSubActor(actorId);
    });
    html.find('.quantity-minus').click(event => {
      const li = $(event.currentTarget).parents(".item");
      this.actor.incDecQuantity( li.data("item-id"), -1 );
    } );
    html.find('.quantity-plus').click(event => {
      const li = $(event.currentTarget).parents(".item");
      this.actor.incDecQuantity( li.data("item-id"), +1 );
    } );

    html.find('.ammo-minus').click(event => {
      const li = $(event.currentTarget).parents(".item")
      this.actor.incDecAmmo( li.data("item-id"), -1 );
    } );
    html.find('.ammo-plus').click(event => {
      const li = $(event.currentTarget).parents(".item")
      this.actor.incDecAmmo( li.data("item-id"), +1 )
    } );
            
    html.find('.roll-charac').click((event) => {
      const characKey = $(event.currentTarget).data("charac-key");
      this.actor.rollCharac(characKey);
    });
    html.find('.roll-perception').click((event) => {
      this.actor.rollPerception("int");
    });
    
    html.find('.roll-direct').click((event) => {
      const rollFormula = $(event.currentTarget).data("roll-formula")
      const rollSource = $(event.currentTarget).data("roll-source")
      Hero6Utility.processDirectRoll( { actorId: this.actor.id, rollFormula: rollFormula, rollSource: rollSource, mode:"directroll"} )
    });
    
    html.find('.roll-item').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      let itemId = li.data("item-id")
      this.actor.rollItem(itemId);
    });
    html.find('.roll-damage').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      let itemId = li.data("item-id")
      this.actor.rollDamage(itemId);
    });
    html.find('.roll-lift-dice').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      let itemId = li.data("item-id")
      this.actor.rollLiftDice(itemId);
    });    
    html.find('.roll-weapon').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      const skillId = li.data("item-id")
      this.actor.rollWeapon(skillId)
    });
    html.find('.roll-maneuver').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      const maneuverId = li.data("maneuver-id")
      this.actor.rollManeuver(maneuverId)
    });
    
    html.find('.hold-action').click((event) => {
      this.actor.holdAction()
    });
    html.find('.abort-action').click((event) => {
      this.actor.abortAction()
    });
    
    html.find(".show-stock-maneuver").click((event) => {
      if ( !this.stockManeuverDisplayed) {
        $('div .maneuver-list').removeClass('maneuver-is-stock');
        this.stockManeuverDisplayed = true
      } else {
        $('div .maneuver-list').addClass('maneuver-is-stock');
        this.stockManeuverDisplayed = false
      }
    });

    html.find('.lock-unlock-sheet').click((event) => {
      this.options.editScore = !this.options.editScore;
      this.render(true);
    });    
    html.find('.item-link a').click((event) => {
      const itemId = $(event.currentTarget).data("item-id");
      const item = this.actor.getOwnedItem(itemId);
      item.sheet.render(true);
    });    
    html.find('.item-equip').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      this.actor.equipItem( li.data("item-id") );
      this.render(true);      
    });

    html.find('.update-field').change(ev => {
      const fieldName = $(ev.currentTarget).data("field-name");
      const fieldType = $(ev.currentTarget).data("dtype");
      let value = ev.currentTarget.value
      if (fieldType.toLowerCase() == "Number") {
        value = Number(value)
      }
      this.actor.update( { [`${fieldName}`]: value } );
    });    
  }
  
  /* -------------------------------------------- */
  /** @override */
  setPosition(options = {}) {
    const position = super.setPosition(options);
    const sheetBody = this.element.find(".sheet-body");
    const bodyHeight = position.height - 192;
    sheetBody.css("height", bodyHeight);
    return position;
  }

  /* -------------------------------------------- */
  async _onDropItem(event, dragData) {
    console.log(">>>>>> DROPPED!!!!")
    const item = fromUuidSync(dragData.uuid)
    if (item == undefined) {
      item = this.actor.items.get( item.id )
    }
    let ret = await this.actor.preprocessItem( event, item, true )
    if ( ret ) {
      super._onDropItem(event, dragData)
    }
  }

  /* -------------------------------------------- */
  /** @override */
  _updateObject(event, formData) {
    // Update the Actor
    return this.object.update(formData);
  }
}
